<?php

namespace Dac\Client;


use GuzzleHttp\Exception\GuzzleException;
use GuzzleHttp\Psr7\Request;
use GuzzleHttp\Client;
use JetBrains\PhpStorm\ArrayShape;
use Proto\Common\RawMessage;

class HttpsClient
{
    public $tlsConfig;
    const OK = 200;

    /**
     * @param $tlsConfig
     */
    public function __construct($tlsConfig)
    {
        $this->tlsConfig = $tlsConfig;
    }

    /**
     * @return Client
     */
    private function getHttpsClient()
    {
        return new Client(
            [
                'timeout' => 70,
                'read_timeout' => 100,
                'connect_timeout' => 100,
                'allow_redirects' => false,
                'verify' => false,
                'cert' => $this->tlsConfig['certPath'],
                'ssl_key' => $this->tlsConfig['keyPath'],
            ]
        );
    }

    /**
     * @param $url
     * @param $header
     * @param $body
     * @return array
     */
    #[ArrayShape(["response" => "false|\Psr\Http\Message\ResponseInterface", "errCode" => "int|mixed", "errMsg" => "string"])]
    public function doPostRequest($url, $header, $body): array
    {
        $request = new Request('POST', $url, $header, $body);
        $response = [];
        $errCode = HttpsClient::OK;
        $errMsg = "";
        try {
            $respRaw = $this->getHttpsClient()->send($request);
            $respMsgList = json_decode($respRaw->getBody());
            foreach ($respMsgList as $k => $v) {
                $r = new RawMessage();
                $r->mergeFromString(base64_decode($v));
                $response[] = $r;
            }
        } catch (GuzzleException $e) {
            $errCode = $e->getCode();
            $errMsg = $e->getResponse()->getBody()->getContents();
        }
        return array("response" => $response, "errCode" => $errCode, "errMsg" => $errMsg);
    }
    public function doResourcePostRequest($url, $header, $body): array
    {
        $request = new Request('POST', $url, $header, $body);
        $errCode = HttpsClient::OK;
        $errMsg = "";
        $respRaw=null;
        try {
            $respRaw = $this->getHttpsClient()->send($request);
        } catch (GuzzleException $e) {
            $errCode = $e->getCode();
            $errMsg = $e->getResponse()->getBody()->getContents();
        }
        return array("response" => $respRaw, "errCode" => $errCode, "errMsg" => $errMsg);
    }
}