<?php

namespace Dac\Model;

use Dac\Utils\Crypto;
use OpenSSLAsymmetricKey;
use OpenSSLCertificate;

class Identity
{
    public OpenSSLCertificate $cert;
    public OpenSSLAsymmetricKey $key;

    public function __construct()
    {

    }

    /**
     * @return false|OpenSSLCertificate
     */
    public function getCert(): bool|OpenSSLCertificate
    {
        return $this->cert;
    }

    /**
     * @return false|string
     */
    public function getCertString()
    {
        $certString = false;
        openssl_x509_export($this->cert, $certString);
        return $certString;
    }

    /**
     * @return false|OpenSSLAsymmetricKey
     */
    public function getKey(): OpenSSLAsymmetricKey|bool
    {
        return $this->key;
    }

    /**
     * @param $certString
     * @param $keyString
     * @return void
     * @throws \Dac\Exception\DACException
     */
    public function loadWithString($certString, $keyString)
    {
        $this->cert = Crypto::loadCert($certString);
        $this->key = Crypto::loadPrivateKey($keyString);
    }

    /**
     * @param $certPath
     * @param $keyPath
     * @return void
     * @throws \Dac\Exception\DACException
     */
    public function loadWithPath($certPath, $keyPath)
    {

        $this->cert = Crypto::readCert($certPath);
        $this->key = Crypto::readPrivateKey($keyPath);
    }


}