<?php

namespace Dac\Utils;

use Dac\Exception\ConfigException;
use Dac\Model\Identity;

class Config
{
    const SharedMode = 'shared';
    const SpecialMode = 'special';
    private $configMap;
    private Identity $identity;


    /**
     * @param string $configPath
     * @throws ConfigException
     * @throws \Dac\Exception\DACException
     */
    public function __construct(string $configPath)
    {
        if (empty($configPath)) {
            throw new ConfigException("config file path is null");
        }
        $this->configMap = yaml_parse_file($configPath);
        if (empty($this->configMap)) {
            throw new ConfigException("fail to load config file");
        }
        if (empty($this->configMap['service']) || $this->configMap['service']['type'] != self::SharedMode) {
            throw new ConfigException("config file is invalid");
        }
        $this->identity = new Identity();

        $this->identity->loadWithPath($this->getIdentityCertPath(), $this->getIdentityKeyPath());
    }

    public function getService()
    {
        return $this->configMap['service'];
    }

    public function getServiceMode()
    {
        if (empty($this->configMap['service']['type'])) {
            return self::SpecialMode;
        }
        return $this->configMap['service']['type'];
    }

    public function getTlsConfig()
    {
        return $this->configMap['client']['tls'];
    }

    public function getIdentityCertPath()
    {
        return $this->configMap['client']['identity']['certPath'];
    }

    public function getIdentityKeyPath()
    {
        return $this->configMap['client']['identity']['keyPath'];
    }

    public function getChainID()
    {
        return $this->configMap['chainCfg']['chainID'];
    }

    public function getProjectID()
    {
        return $this->configMap['service']['projectID'];
    }

    /**
     * @return Identity
     */
    public function getIdentity(): Identity
    {
        return $this->identity;
    }

    /**
     * @param string $name
     * @return mixed
     * @throws ConfigException
     */
    public function getIdentityByName(string $name)
    {
        $identities = $this->configMap['identities'];
        var_dump($identities);
        echo "<br>";
        var_dump(empty($identities));
        echo "<br>";
        var_dump(count($identities));
        echo "<br>";
        if(empty($identities) || count($identities) == 0){
            throw new ConfigException("identities not set");
        }
        $target = $identities[$name];
        if (empty($target) || empty($target['certPath']) || empty($target['keyPath'])){
            throw new ConfigException("identity not exist");
        }
        return $target;
    }

    public function getContractName()
    {
        return $this->configMap['chainCfg']['contractName'];
    }

    public function getOrgCaCert()
    {
        return $this->configMap['orgCa']['certPath'];
    }

    public function getOrgCaKey()
    {
        return $this->configMap['orgCa']['keyPath'];
    }

    public function getOpensslCnf()
    {
        if(empty($this->configMap['opensslCnf'])){
            return "";
        }
        return $this->configMap['opensslCnf'];
    }

    public function updateIdentity(string $cert, string $key)
    {
        $id = new Identity();
        $id->loadWithString($cert, $key);
        $this->identity = $id;
    }

    public function setIdentity(Identity $identity)
    {
        $this->identity = $identity;
    }
}